# -*- coding: utf-8 -*-
from setuphelpers import *

bin_contains = "FBReader"
appx_package = "FBReader.ORGLimited.FBReader"
appx_dir = makepath(programfiles, "WindowsAppsInstallers")
file_extension = "msix"


def install():
    # Declaring local variables
    package_version = control.get_software_version()
    bin_name = glob.glob("*%s*.%s" % (bin_contains, file_extension))[0]
    bin_path = makepath(appx_dir, bin_name)

    # Checking minimum Windows version
    if windows_version() >= WindowsVersions.Windows10v1809:
        # Copying the software
        if not isdir(appx_dir):
            mkdirs(appx_dir)
        else:
            for appx_file in glob.glob("%s/*%s*.%s" % (appx_dir, bin_contains, file_extension)):
                if not package_version in appx_file:
                    remove_file(appx_file)
        if not isfile(bin_path):
            print("Copying: %s to: %s" % (bin_name, appx_dir))
            filecopyto(bin_name, appx_dir)
    else:
        error(
            "This Windows version (%s) need to be upgraded to minimum version (%s) to use this package"
            % (windows_version(), WindowsVersions.Windows10v1809)
        )


def uninstall():
    # Declaring local variables
    package_version = control.get_software_version()
    bin_path = glob.glob(makepath(appx_dir, "*%s*.%s" % (bin_contains, file_extension)))[0]

    # Uninstalling the package
    remove_appx(appx_package)
    if isfile(bin_path):
        remove_file(bin_path)
    if isdir(appx_dir) and dir_is_empty(appx_dir):
        print("Removing: %s since he is empty" % (appx_dir))
        remove_tree(appx_dir)


def session_setup():
    # Declaring local variables
    package_version = control.get_software_version()
    app_name = control.name
    bin_path = glob.glob(makepath(appx_dir, "*%s*.%s" % (bin_contains, file_extension)))[0]
    bin_name = bin_path.split("\\")[-1]

    # Installing the software in user env
    appx_version = get_powershell_str("Get-AppxPackage -Name %s" % appx_package, "Version")
    if not appx_version or appx_version < package_version or force:
        print("Installing: %s" % bin_name)
        run_powershell('Add-AppxPackage -Path "%s"' % bin_path)
    else:
        print("%s is installed in correct version (%s)" % (app_name, appx_version))
